"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.saveFile = exports.buildErrors = void 0;
const path_1 = __importDefault(require("path"));
const fs_1 = __importDefault(require("fs"));
const mustache_1 = require("mustache");
const config_1 = require("./config");
function buildErrors(type) {
    return __awaiter(this, void 0, void 0, function* () {
        const tpl = yield loadTemplate();
        const destDirPath = path_1.default.join(__dirname + '/' + type);
        const fileNames = [];
        const mapping = type === 'client' ? config_1.ClientErrorOptions : config_1.ServerErrorOptions;
        for (let key in mapping) {
            const fileName = mapping[key].statusCode + '-' + (mapping[key].code).toLowerCase().replaceAll('_', '-') + '.ts';
            const destFilePath = path_1.default.join(destDirPath + '/' + fileName);
            const content = mustache_1.render(tpl, Object.assign({ namespaceFile: 'index.ts', decorateMessage: type === 'server', logMessage: type === 'server', class: key }, mapping[key]));
            yield saveFile(content, destFilePath);
            fileNames.push(fileName);
        }
        const content = fileNames.map(fileName => {
            const parts = fileName.split('.');
            parts.pop();
            return `export * from "./${parts.join('.')}";`;
        }).reduce((prev, current) => prev + "\n" + current);
        const destFilePath = path_1.default.join(destDirPath + '/index.ts');
        yield saveFile(content, destFilePath);
    });
}
exports.buildErrors = buildErrors;
function saveFile(content, filePath) {
    return __awaiter(this, void 0, void 0, function* () {
        return new Promise(((resolve, reject) => {
            return fs_1.default.writeFile(filePath, content, (err) => {
                if (err)
                    reject(err);
                resolve();
            });
        }));
    });
}
exports.saveFile = saveFile;
function loadTemplate() {
    return __awaiter(this, void 0, void 0, function* () {
        const tplPath = path_1.default.join(__dirname + '/../template/error.tpl');
        return new Promise((resolve, reject) => {
            return fs_1.default.readFile(tplPath, ({ encoding: 'utf-8' }), (err, data) => {
                if (err)
                    reject(err);
                resolve(data);
            });
        });
    });
}
//# sourceMappingURL=build.js.map